@@ -89,7 +89,11 @@ def train():
             logging_config.configure_logger(env.log_level)
 
             mpi_enabled = env.additional_framework_parameters.get(params.MPI_ENABLED)
-            runner_type = runner.RunnerType.MPI if mpi_enabled else runner.RunnerType.Process
+            runner_type = (
+                runner.RunnerType.MPI
+                if mpi_enabled and (env.current_instance_group in env.distribution_instance_groups)
+                else runner.RunnerType.Process
+            )
 
             entry_point.run(
                 env.module_dir,
